const  codec = require("./../../index.js");

//const dropDown = document.querySelector(".typeDropDown");
const dropDownList = document.querySelector(".dropDownList");
const dropDownInput = document.querySelector(".typeInput");
const payloadInput = document.querySelector(".payloadInput");
const decodeButton = document.querySelector(".decodeButton");
const resultArea = document.querySelector(".resultArea");

let selectedType = null;

const deviceTypes = [
    {
        id: "600-021",
        name: "TX T&H AMB",
        defaultPayload: "00006D04130100E501200000000000080000"
    },
    {
        id: "600-022",
        name: "TX VOC/T&H AMB",
        defaultPayload: "00007705110100E3011F0014000000280000"
    },
    {
        id: "600-023",
        name: "TX CO2/VOC/T&H AMB",
        defaultPayload: "000081060E1100D3016500AD026100800000"
    },
    {
        id: "600-024",
        name: "TX CO2/T&H AMB",
        defaultPayload: "0000810E0E1100D301650000026100800000"
    },
    {
        id: "600-031",
        name: "TX TEMP INS",
        defaultPayload: "00008A07070100CD000000020000"
    },
    {
        id: "600-032",
        name: "TX TEMP CONT1",
        defaultPayload: "0000DC0F0A0100D0000000000000"
    },
    {
        id: "600-033",
        name: "TX TEMP CONT1 MP",
        defaultPayload: "0000DC100A0100D0000000000000"
    },
    {
        id: "600-034",
        name: "TX T&H EXT",
        defaultPayload: "0000D10E0A0100CA018200010000"
    },
    {
        id: "600-035",
        name: "TX 4/20mA",
        defaultPayload: "0000C70D0A01000200020000"
    },
    {
        id: "600-036",
        name: "TX PULSE",
        defaultPayload: "000095080C0100000020000000170000001E00000000"
    },
    {
        id: "600-037",
        name: "TX PULSE ATEX",
        defaultPayload: "0000A0090D01000000120000001A0000001800000000"
    },
    {
        id: "600-038",
        name: "TX PULSE LED",
        defaultPayload: "0000AA0A0D0100000000000000000000000A00000060"
    },
    {
        id: "600-039",
        name: "TX CONTACT",
        defaultPayload: "0000B40B0E0100000018000000280000005600040001"
    },
    {
        id: "600-232",
        name: "TX TEMP CONT2",
        defaultPayload: "0000BD0C0A0100CE00CA00010000"
    },
    {
        id: "600-233",
        name: "TX TEMP CONT2 MP",
        defaultPayload: "0000BD110A0100CE00CA00010000"
    }
];

selectedType = deviceTypes[0];

payloadInput.value = selectedType.defaultPayload;
dropDownInput.value = createLabel(selectedType);
dropDownInput.addEventListener("click", () => {
    dropDownList.classList.toggle("show");
});

for (const type in deviceTypes) {
    dropDownList.innerHTML += `<li>${createLabel(deviceTypes[type])}</li>`
}

document.querySelectorAll("li").forEach(li => {
    li.addEventListener("click", e => {
        const devInfo = e.target.innerText.trim();
        const name = devInfo.substring(0, devInfo.indexOf(" 600"));
        const id = devInfo.substring(devInfo.indexOf("600"), devInfo.length);

        selectedType = deviceTypes.filter(type => type.id === id && type.name === name);

        dropDownInput.value = createLabel(selectedType[0]);
        payloadInput.value  = selectedType[0].defaultPayload;
    });
});

decodeButton.addEventListener("click", () => {
    const val = dropDownInput.value;
    const type = val.substring(val.indexOf("600"), val.length);
    const payload = payloadInput.value.trim();
    const Decoder = new codec.Decoder(type);
    const decodedData = Decoder.decode(payload);

    if(decodedData.error){
        resultArea.value = JSON.stringify(decodedData.error);
    }else{
        resultArea.value = JSON.stringify(decodedData.result, null, 2);
    }
});


window.onclick = function (event) {
    if (!event.target.matches('.typeInput')) {
        let dropdowns = document.getElementsByClassName("dropDownList");
        let i;
        for (i = 0; i < dropdowns.length; i++) {
            let openDropdown = dropdowns[i];
            if (openDropdown.classList.contains('show')) {
                openDropdown.classList.remove('show');
            }
        }
    }
}


function createLabel (devType) {
    return devType.name + " " + devType.id;
}

